from setuptools import setup

setup(
    name='nnc',
    version='0.0.1',
    description='Neural Network Control',
    long_description='A package for neural network control of deterministic continuous time differentiable systems on graphs.',
    url='https://www.example.com',
    author='Thomas Asikis',
    author_email='asikist@ethz.ch',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)